@@ -4,14 +4,11 @@
 #define OPENBLAS_ARCH_ARM 1
 #define OPENBLAS_C_GCC 1
 #define OPENBLAS___32BIT__ 1
+#define OPENBLAS_HAVE_C11 1
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
 #define OPENBLAS_ARMV7 
-#define OPENBLAS_HAVE_VFP 
-#define OPENBLAS_HAVE_VFPV3 
-#define OPENBLAS_HAVE_NEON 
-#define OPENBLAS_HAVE_VFPV4 
 #define OPENBLAS_L1_DATA_SIZE 65536
 #define OPENBLAS_L1_DATA_LINESIZE 32
 #define OPENBLAS_L2_SIZE 512488
@@ -19,9 +16,12 @@
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
 #define OPENBLAS_L2_ASSOCIATIVE 4
+#define OPENBLAS_HAVE_VFPV3 
+#define OPENBLAS_HAVE_VFP 
+#define OPENBLAS_CORE_ARMV7 
 #define OPENBLAS_CHAR_CORENAME "ARMV7"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.3 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.13 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -58,6 +58,11 @@ typedef long BLASLONG;
 typedef unsigned long BLASULONG;
 #endif
 
+#ifndef BFLOAT16
+#include <stdint.h>
+typedef uint16_t bfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
@@ -115,4 +120,9 @@ typedef int blasint;
   #define openblas_complex_xdouble_real(z)           ((z).real)
   #define openblas_complex_xdouble_imag(z)           ((z).imag)
 #endif
+
+/* Inclusion of Linux-specific header is needed for definition of cpu_set_t. */
+#ifdef OPENBLAS_OS_LINUX
+#include <sched.h>
+#endif
 #endif /* OPENBLAS_CONFIG_H */
